@@ -293,9 +293,9 @@ class Curve(
 
     @classmethod
     def from_list(cls, args: List[Any]) -> "Curve":
-        point_count = args[7]
-        weights_count = args[8]
-        knots_count = args[9]
+        point_count = int(args[7])
+        weights_count = int(args[8])
+        knots_count = int(args[9])
 
         points_start = 10
         weights_start = 10 + point_count
@@ -303,7 +303,7 @@ class Curve(
         knots_end = knots_start + knots_count
 
         return cls(
-            degree=args[1],
+            degree=int(args[1]),
             periodic=bool(args[2]),
             rational=bool(args[3]),
             closed=bool(args[4]),
@@ -632,7 +632,7 @@ class Brep(
     bbox: Box = None
     area: float = None
     volume: float = None
-    displayValue: Mesh = None
+    _displayValue: List[Mesh] = None
     Surfaces: List[Surface] = None
     Curve3D: List[Base] = None
     Curve2D: List[Base] = None
@@ -648,6 +648,18 @@ class Brep(
             child._Brep = self
         return children
 
+    # set as prop for now for backwards compatibility
+    @property
+    def displayValue(self) -> List[Mesh]:
+        return self._displayValue
+
+    @displayValue.setter
+    def displayValue(self, value):
+        if isinstance(value, Mesh):
+            self._displayValue = [value]
+        elif isinstance(value, list):
+            self._displayValue = value
+
     @property
     def Edges(self) -> List[BrepEdge]:
         return self._inject_self_into_children(self._Edges)
